netstring

module
v0.0.0-...-014d6e9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 22, 2021 License: GPL-3.0

README

netstring

Motivation

In case of unreliable io you want a transmission envelope which ensures that the payload arrives completely.

Installation

go get -u github.com/4thel00z/netstring

Usage

package main

import (
	"github.com/4thel00z/netstring/v1/pkg/netstring"
	"log"
	"strings"
)

func main() {
	ns, err := netstring.FromReader(strings.NewReader("4:Test,"))
	if err != nil {
		log.Fatalln(err)
	}
	log.Println(ns)
}

License

This project is licensed under the GPL-3 license.

Directories

Path Synopsis
v1

Jump to